==> ispell-3.2.06.tar.gz: ispell-3.2.06/version.h <==
/*
 * Since the strings in this file are printed out when the "-v" switch is
 * given to ispell, you may want to translate them into your native language.
 * However, any translation of these strings MUST accurately preserve the
 * legal rights under international law;  you may wish to consult a lawyer
 * about this since you will be responsible for the results of any
 * incorrect translation.
 */

static char * Version_ID[] = {
    "@(#) International Ispell Version 3.2.06 08/01/01",
    "@(#) Copyright (c), 1983, by Pace Willisson",
    "@(#) International version Copyright (c) 1987, 1988, 1990-1995, 1999,",
    "@(#) 2001, by Geoff Kuenning, Claremont, CA.  All rights reserved.",
    "@(#)",
    "@(#) Report bugs to ispell-bugs@itcorp.com.  Report Emacs-related bugs",
    "@(#) to ispell-el-bugs@itcorp.com.",
    "@(#)",
    "@(#) Redistribution and use in source and binary forms, with or without",
    "@(#) modification, are permitted provided that the following conditions",
    "@(#) are met:",
    "@(#)",
    "@(#) 1. Redistributions of source code must retain the above copyright",
    "@(#)    notice, this list of conditions and the following disclaimer.",
    "@(#) 2. Redistributions in binary form must reproduce the above",
    "@(#)    copyright notice, this list of conditions and the following",
    "@(#)    disclaimer in the documentation and/or other materials provided",
    "@(#)    with the distribution.",
    "@(#) 3. All modifications to the source code must be clearly marked as",
    "@(#)    such.  Binary redistributions based on modified source code",
    "@(#)    must be clearly marked as modified versions in the documentation",
    "@(#)    and/or other materials provided with the distribution.",
    "@(#) 4. Any web site or other electronic service that offers ispell for",
    "@(#)    download or other electronic transfer as a separate entity, in",
    "@(#)    either source or binary form, must also include a prominent",
    "@(#)    statement indicating that information about ispell can be",
    "@(#)    obtained from the following Web site URL:",
    "@(#)	http://fmg-www.cs.ucla.edu/geoff/ispell.html",
    "@(#)    If the offering service supports hyperlinks, the aforementioned",
    "@(#)    Web site must also be offered as a hyperlink.  Condition #4 does",
    "@(#)    not apply if ispell is offered only as part of a larger,",
    "@(#)    aggregated product such as a word processor or packaged",
    "@(#)    operating system.",
    "@(#) 5. The name of Geoff Kuenning may not be used to endorse or promote",
    "@(#)    products derived from this software without specific prior",
    "@(#)    written permission.",
    "@(#)",
    "@(#) THIS SOFTWARE IS PROVIDED BY GEOFF KUENNING AND CONTRIBUTORS ``AS",
    "@(#) IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT",
    "@(#) LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS",
    "@(#) FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL GEOFF",
    "@(#) KUENNING OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,",
    "@(#) INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES",
    "@(#) (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR",
    "@(#) SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)",
    "@(#) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,",
    "@(#) STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)",
    "@(#) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED",
    "@(#) OF THE POSSIBILITY OF SUCH DAMAGE.",
    NULL
};

static char RCS_Version_ID[] =
    "$Id: version.h,v 1.53 2001/08/01 22:16:57 geoff Exp $";

/*
 * $Log: version.h,v $
 * Revision 1.53  2001/08/01 22:16:57  geoff
 * Bump version for new release.
 *
 * Revision 1.52  2001/07/25 21:51:46  geoff
 * Minor license update.
 *
 * Revision 1.51  2001/07/23 22:11:08  geoff
 * Update version for a new release.
 *
 * Revision 1.50  2001/07/23 20:24:04  geoff
 * Update the license.
 *
 * Revision 1.49  2001/06/14 09:11:11  geoff
 * Minor patch for compilation problems on some machines.
 *
 * Revision 1.48  2001/06/10 23:54:57  geoff
 * Bump verson to reflect latest bug fix.
 *
 * Revision 1.47  2001/06/06 23:50:26  geoff
 * Bump to 3.2.02 in preparation for release.
 *
 * Revision 1.46  1999/01/18 02:15:44  geoff
 * Bump to next version
 *
 * Revision 1.45  1999/01/07  01:23:00  geoff
 * Update the copyright and the version number preparatory to release.
 *
 * Revision 1.44  1995/10/11  05:03:28  geoff
 * Upgrade to patch level 20
 *
 * Revision 1.43  1995/10/11  04:58:26  geoff
 * Upgrade to patch 19
 *
 * Revision 1.42  1995/01/15  01:23:26  geoff
 * Upgrade to patch level 18
 *
 * Revision 1.41  1995/01/15  01:14:30  geoff
 * Upgrade to patch level 17
 *
 * Revision 1.40  1995/01/15  01:03:55  geoff
 * Upgrade to patch level 16
 *
 * Revision 1.39  1995/01/15  01:01:01  geoff
 * Upgrade to patch level 15
 *
 * Revision 1.38  1995/01/15  00:54:19  geoff
 * Upgrade to patch level 14
 *
 * Revision 1.37  1994/11/21  07:03:01  geoff
 * Update to patch level 13.
 *
 * Revision 1.36  1994/11/01  06:28:31  geoff
 * Update to patch level 12
 *
 * Revision 1.35  1994/11/01  06:12:42  geoff
 * Update to patch level 11
 *
 * Revision 1.34  1994/11/01  06:01:15  geoff
 * Update to patch level 10
 *
 * Revision 1.33  1994/11/01  05:36:43  geoff
 * Update to patch level 9
 *
 * Revision 1.32  1994/05/25  04:38:59  geoff
 * Update to patch level 8
 *
 * Revision 1.31  1994/05/18  03:07:26  geoff
 * Update to patch level 7
 *
 * Revision 1.30  1994/05/17  06:21:05  geoff
 * Version update for ispell.el release
 *
 * Revision 1.29  1994/04/27  04:14:18  geoff
 * Update to patch level 5
 *
 * Revision 1.28  1994/03/21  02:00:50  geoff
 * Update to patch level 4
 *
 * Revision 1.27  1994/02/23  04:52:31  geoff
 * Update to latest version.
 *
 * Revision 1.26  1994/02/08  05:59:20  geoff
 * Update version
 *
 * Revision 1.25  1994/02/07  08:58:28  geoff
 * Get rid of a comma that confuses patch
 *
 * Revision 1.24  1994/02/07  08:24:23  geoff
 * Upate patch level
 *
 * Revision 1.23  1994/01/25  07:12:21  geoff
 * Get rid of all old RCS log lines in preparation for the 3.1 release.
 *
 */

==> ispell_3.3.02.orig.tar.gz: ispell-3.3.02/version.h <==
#ifndef VERSION_H_INCLUDED
#define VERSION_H_INCLUDED
/*
 * Since the strings in this file are printed out when the "-v" switch is
 * given to ispell, you may want to translate them into your native language.
 * However, any translation of these strings MUST accurately preserve the
 * legal rights under international law;  you may wish to consult a lawyer
 * about this since you will be responsible for the results of any
 * incorrect translation.
 */

static char * Version_ID[] = {
    "@(#) International Ispell Version 3.3.02 12 Jun 2005",
    "@(#) Copyright (c), 1983, by Pace Willisson",
    "@(#) International version Copyright (c) 1987, 1988, 1990-1995, 1999,",
    "@(#) 2001, 2002, 2005 by Geoff Kuenning, Claremont, CA.",
    "@(#) All rights reserved.",
    "@(#)",
    "@(#) The official ispell Web site is at:",
    "@(#)",
    "@(#)     http://www.lasr.cs.ucla.edu/geoff/ispell.html",
    "@(#)",
    "@(#) You should always check that site to see whether you have the",
    "@(#) latest version of ispell.",
    "@(#)",
    "@(#) Report bugs to ispell-bugs@itcorp.com.  Report Emacs-related bugs",
    "@(#) to ispell-el-bugs@itcorp.com.",
    "@(#)",
    "@(#) Redistribution and use in source and binary forms, with or without",
    "@(#) modification, are permitted provided that the following conditions",
    "@(#) are met:",
    "@(#)",
    "@(#) 1. Redistributions of source code must retain the above copyright",
    "@(#)    notice, this list of conditions and the following disclaimer.",
    "@(#) 2. Redistributions in binary form must reproduce the above",
    "@(#)    copyright notice, this list of conditions and the following",
    "@(#)    disclaimer in the documentation and/or other materials provided",
    "@(#)    with the distribution.",
    "@(#) 3. All modifications to the source code must be clearly marked as",
    "@(#)    such.  Binary redistributions based on modified source code",
    "@(#)    must be clearly marked as modified versions in the documentation",
    "@(#)    and/or other materials provided with the distribution.",
    "@(#) 4. The code that causes the 'ispell -v' command to display a",
    "@(#)    prominent link to the official ispell Web site may not be",
    "@(#)    removed.",
    "@(#) 5. The name of Geoff Kuenning may not be used to endorse or promote",
    "@(#)    products derived from this software without specific prior",
    "@(#)    written permission.",
    "@(#)",
    "@(#) THIS SOFTWARE IS PROVIDED BY GEOFF KUENNING AND CONTRIBUTORS ``AS",
    "@(#) IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT",
    "@(#) LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS",
    "@(#) FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL GEOFF",
    "@(#) KUENNING OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,",
    "@(#) INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES",
    "@(#) (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR",
    "@(#) SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)",
    "@(#) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,",
    "@(#) STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)",
    "@(#) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED",
    "@(#) OF THE POSSIBILITY OF SUCH DAMAGE.",
    NULL
};

static char RCS_Version_ID[] =
    "$Id: version.h,v 1.59 2005/06/11 22:49:44 geoff Exp $";

#endif /* VERSION_H_INCLUDED */
